==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/lt_LT.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Slaptažodis įeina į 1,000,000 populiariausiai naudojamų slaptažodžių sąrašą. Prašome pasirinkti kitą.",
    "Password needs to be at least %s characters long" : "Slaptažodis turi būti bent %s simbolių ilgio",
    "Password needs to contain at least one numeric character." : "Slaptažodyje turi būti bent vienas skaičius.",
    "Password needs to contain at least one special character." : "Slaptažodyje turi būti bent vienas specialus simbolis.",
    "Password needs to contain at least one lower and one upper case character." : "Slaptažodyje turi būti bent vienas didžiųjų ir mažųjų raidžių simbolis.",
    "Password policy" : "Slaptažodžio politika",
    "Allows admins to configure a password policy" : "Leidžia administratoriams konfigūruoti slaptažodžių politiką",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Leisti administratoriams apibrėžti tam tikras išankstines sąlygas slaptažodžiui, pvz., priverstinis mažiausias slaptažodžio ilgis",
    "Minimal length" : "Minimalus ilgis",
    "Forbid common passwords" : "Uždrausti paplitusius slaptažodžius",
    "Enforce upper and lower case characters" : "Versti naudoti didžiąsias ir mažąsias raides",
    "Enforce numeric characters" : "Versti naudoti skaitmenų simbolius",
    "Enforce special characters" : "Versti naudoti specialius simbolius"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/lt_LT.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Slaptažodis įeina į 1,000,000 populiariausiai naudojamų slaptažodžių sąrašą. Prašome pasirinkti kitą.",
    "Password needs to be at least %s characters long" : "Slaptažodis turi būti bent %s simbolių ilgio",
    "Password needs to contain at least one numeric character." : "Slaptažodyje turi būti bent vienas skaičius.",
    "Password needs to contain at least one special character." : "Slaptažodyje turi būti bent vienas specialus simbolis.",
    "Password needs to contain at least one lower and one upper case character." : "Slaptažodyje turi būti bent vienas didžiųjų ir mažųjų raidžių simbolis.",
    "Password policy" : "Slaptažodžio politika",
    "Allows admins to configure a password policy" : "Leidžia administratoriams konfigūruoti slaptažodžių politiką",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Leisti administratoriams apibrėžti tam tikras išankstines sąlygas slaptažodžiui, pvz., priverstinis mažiausias slaptažodžio ilgis",
    "Forbid common passwords" : "Uždrausti paplitusius slaptažodžius",
    "Enforce upper and lower case characters" : "Versti naudoti didžiąsias ir mažąsias raides",
    "Enforce numeric characters" : "Versti naudoti skaitmenų simbolius",
    "Enforce special characters" : "Versti naudoti specialius simbolius",
    "Minimal length" : "Minimalus ilgis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
